==> ogre-13.1.1-1-x86_64.pkg.tar.zst: usr/share/doc/OGRE/api/html/_instancing.js <==
var _instancing =
[
    [ "Static Geometry", "_instancing.html#Static-Geometry", null ],
    [ "Instance Manager", "_instancing.html#Instance-Manager", null ],
    [ "Static Geometry vs Instancing", "_instancing.html#Static-Geometry-vs-Instancing", null ],
    [ "What is instancing?", "_what_is_instancing.html", [
      [ "Instancing 101", "_what_is_instancing.html#Instancing101", [
        [ "Instances per batch", "_what_is_instancing.html#InstancesPerBatch", null ]
      ] ],
      [ "Techniques", "_what_is_instancing.html#InstancingTechniques", [
        [ "ShaderBased", "_what_is_instancing.html#InstancingTechniquesShaderBased", null ],
        [ "VTF (Software)", "_what_is_instancing.html#InstancingTechniquesVTFSoftware", null ],
        [ "HW VTF", "_what_is_instancing.html#InstancingTechniquesHWVTF", [
          [ "HW VTF LUT", "_what_is_instancing.html#InstancingTechniquesHW", null ]
        ] ],
        [ "HW Basic", "_what_is_instancing.html#InstancingTechniquesHWBasic", null ]
      ] ],
      [ "Custom parameters", "_what_is_instancing.html#InstancingCustomParameters", null ],
      [ "Supporting multiple submeshes", "_what_is_instancing.html#InstancingMultipleSubmeshes", null ],
      [ "Defragmenting batches", "_what_is_instancing.html#InstancingDefragmentingBatches", [
        [ "What is batch fragmentation?", "_what_is_instancing.html#InstancingDefragmentingBatchesIntro", null ],
        [ "Prevention: Avoiding fragmentation", "_what_is_instancing.html#InstancingDefragmentingBatchesPrevention", null ],
        [ "Cure: Defragmenting on the fly", "_what_is_instancing.html#InstancingDefragmentingBatchesOnTheFly", null ]
      ] ],
      [ "Troubleshooting", "_what_is_instancing.html#InstancingTroubleshooting", null ]
    ] ]
];

==> ogre-14.4.1-1-x86_64.pkg.tar.zst: usr/share/doc/OGRE/api/html/_instancing.js <==
var _instancing =
[
    [ "Static Geometry", "_instancing.html#Static-Geometry", null ],
    [ "Instance Manager", "_instancing.html#Instance-Manager", null ],
    [ "Static Geometry vs Instancing", "_instancing.html#Static-Geometry-vs-Instancing", null ],
    [ "Instancing User-Guide", "_what_is_instancing.html", [
      [ "Instances per batch", "_what_is_instancing.html#InstancesPerBatch", null ],
      [ "Techniques", "_what_is_instancing.html#InstancingTechniques", [
        [ "ShaderBased", "_what_is_instancing.html#InstancingTechniquesShaderBased", null ],
        [ "VTF (Software)", "_what_is_instancing.html#InstancingTechniquesVTFSoftware", null ],
        [ "HW VTF", "_what_is_instancing.html#InstancingTechniquesHWVTF", [
          [ "HW VTF LUT", "_what_is_instancing.html#InstancingTechniquesHW", null ]
        ] ],
        [ "HW Basic", "_what_is_instancing.html#InstancingTechniquesHWBasic", null ]
      ] ],
      [ "Custom parameters", "_what_is_instancing.html#InstancingCustomParameters", null ],
      [ "Supporting multiple submeshes", "_what_is_instancing.html#InstancingMultipleSubmeshes", null ],
      [ "Defragmenting batches", "_what_is_instancing.html#InstancingDefragmentingBatches", [
        [ "What is batch fragmentation?", "_what_is_instancing.html#InstancingDefragmentingBatchesIntro", null ],
        [ "Prevention: Avoiding fragmentation", "_what_is_instancing.html#InstancingDefragmentingBatchesPrevention", null ],
        [ "Cure: Defragmenting on the fly", "_what_is_instancing.html#InstancingDefragmentingBatchesOnTheFly", null ]
      ] ],
      [ "Troubleshooting", "_what_is_instancing.html#InstancingTroubleshooting", null ]
    ] ]
];
